pub struct OrderEmulatedSpec {
pub trader_id: TraderId,
pub strategy_id: StrategyId,
pub instrument_id: InstrumentId,
pub client_order_id: ClientOrderId,
pub event_id: UUID4,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Test-only fluent spec for OrderEmulated.
All fields carry sensible defaults so callers only set what differs.
build() constructs the event through OrderEmulated::new so any future invariants
added to the production constructor are exercised by tests built on this spec.
Fields
trader_id: TraderIdstrategy_id: StrategyIdinstrument_id: InstrumentIdclient_order_id: ClientOrderIdevent_id: UUID4ts_event: UnixNanosts_init: UnixNanosImplementations
Sourceimpl OrderEmulatedSpec
impl OrderEmulatedSpec
Sourcepub fn builder() -> OrderEmulatedSpecBuilder
pub fn builder() -> OrderEmulatedSpecBuilder
Create an instance of OrderEmulatedSpec using the builder syntax